@@ -1,14 +1,14 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 1230 2011-01-29 17:10:18Z icemac $
+# $Id: tests.py 1284 2011-07-26 18:54:04Z icemac $
 
 import icemac.addressbook.testing
 import icemac.ab.importer.browser.testing
 
 
 def test_suite():
-    return icemac.addressbook.testing.FunctionalDocFileSuite(
+    return icemac.addressbook.testing.DocFileSuite(
         "constraints.txt",
         "edgecases.txt",
         "keywords.txt",
